aboutsummaryrefslogtreecommitdiffstats
path: root/Demos/Device/ClassDriver/AudioInput/AudioInput.c
diff options
context:
space:
mode:
Diffstat (limited to 'Demos/Device/ClassDriver/AudioInput/AudioInput.c')
-rw-r--r--Demos/Device/ClassDriver/AudioInput/AudioInput.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/Demos/Device/ClassDriver/AudioInput/AudioInput.c b/Demos/Device/ClassDriver/AudioInput/AudioInput.c
index 59d2129f4..3aa26ae85 100644
--- a/Demos/Device/ClassDriver/AudioInput/AudioInput.c
+++ b/Demos/Device/ClassDriver/AudioInput/AudioInput.c
@@ -112,7 +112,7 @@ void ProcessNextSample(void)
}
/** Event handler for the library USB Connection event. */
-void EVENT_USB_Connect(void)
+void EVENT_USB_Device_Connect(void)
{
LEDs_SetAllLEDs(LEDMASK_USB_ENUMERATING);
@@ -123,7 +123,7 @@ void EVENT_USB_Connect(void)
}
/** Event handler for the library USB Disconnection event. */
-void EVENT_USB_Disconnect(void)
+void EVENT_USB_Device_Disconnect(void)
{
/* Stop the sample reload timer */
TCCR0B = 0;
@@ -132,7 +132,7 @@ void EVENT_USB_Disconnect(void)
}
/** Event handler for the library USB Configuration Changed event. */
-void EVENT_USB_ConfigurationChanged(void)
+void EVENT_USB_Device_ConfigurationChanged(void)
{
LEDs_SetAllLEDs(LEDMASK_USB_READY);
@@ -140,8 +140,8 @@ void EVENT_USB_ConfigurationChanged(void)
LEDs_SetAllLEDs(LEDMASK_USB_ERROR);
}
-/** Event handler for the library USB Unhandled Control Packet event. */
-void EVENT_USB_UnhandledControlPacket(void)
+/** Event handler for the library USB Unhandled Control Request event. */
+void EVENT_USB_Device_UnhandledControlRequest(void)
{
- Audio_Device_ProcessControlPacket(&Microphone_Audio_Interface);
+ Audio_Device_ProcessControlRequest(&Microphone_Audio_Interface);
}